# eric7.PipInterface.PipDialog

Module implementing a dialog showing the output of a pip command.

### Global Attributes

None

### Classes

PipDialog | Class implementing a dialog showing the output of a 'python -m pip' command.

### Functions

None

## PipDialog

Class implementing a dialog showing the output of a 'python -m pip' command.

### Derived from

QDialog, Ui_PipDialog

### Class Attributes

None

### Class Methods

None

### Methods

PipDialog | Constructor
__addOutput | Private method to add some text to the output pane.
__cancel | Private slot to cancel the current action.
__finish | Private slot called when the process finished or the user pressed the button.
__procFinished | Private slot connected to the finished signal.
__readStderr | Private slot to handle the readyReadStandardError signal.
__readStdout | Private slot to handle the readyReadStandardOutput signal.
closeEvent | Protected slot implementing a close event handler.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
startProcess | Public slot used to start the process.
startProcesses | Public method to issue a list of commands to be executed.

### Static Methods

None

#### PipDialog (Constructor)

PipDialog(text, parent=None)

Constructor

text (str)
  text to be shown by the label
parent (QWidget)
  reference to the parent widget

#### PipDialog.__addOutput

__addOutput(txt)

Private method to add some text to the output pane.

txt (str)
  text to be added

#### PipDialog.__cancel

__cancel()

Private slot to cancel the current action.

#### PipDialog.__finish

__finish()

Private slot called when the process finished or the user pressed the button.

#### PipDialog.__procFinished

__procFinished(_exitCode, _exitStatus)

Private slot connected to the finished signal.

_exitCode (int)
  exit code of the process (unused)
_exitStatus (QProcess.ExitStatus)
  exit status of the process (unused)

#### PipDialog.__readStderr

__readStderr()

Private slot to handle the readyReadStandardError signal.

It reads the error output of the process and inserts it into the error pane.

#### PipDialog.__readStdout

__readStdout()

Private slot to handle the readyReadStandardOutput signal.

It reads the output of the process, formats it and inserts it into the contents pane.

#### PipDialog.closeEvent

closeEvent(e)

Protected slot implementing a close event handler.

e (QCloseEvent)
  close event

#### PipDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button (QAbstractButton)
  button that was clicked

#### PipDialog.startProcess

startProcess(cmd, args, showArgs=True)

Public slot used to start the process.

cmd (str)
  name of the pip executable to be used
args (list of str)
  list of arguments for the process
showArgs (bool)
  flag indicating to show the arguments

Return:
  flag indicating a successful start of the process

Return Type:
  bool

#### PipDialog.startProcesses

startProcesses(processParams)

Public method to issue a list of commands to be executed.

processParams (list of tuples of (str, list of str))
  list of tuples containing the command and arguments

Return:
  flag indicating a successful start of the first process

Return Type:
  bool

Up